@@ -191,6 +191,42 @@ pub enum AZSelectionScheme {
     Random,
 }
 
+/// AWSResourceReference is a reference to a specific AWS resource by ID, ARN, or filters.
+/// Only one of ID, ARN or Filters may be specified. Specifying more than one will result in
+/// a validation error.
+#[derive(Clone, Debug, Default, Serialize, Deserialize)]
+#[serde(rename_all = "camelCase")]
+#[skip_serializing_none]
+pub struct AWSResourceReference {
+    /// ID of resource
+    // +optional
+    pub id: Option<String>, //`json:"id,omitempty"`
+
+    /// ARN of resource
+    // +optional
+    pub arn: Option<String>, //`json:"arn,omitempty"`
+
+    /// Filters is a set of key/value pairs used to identify a resource
+    /// They are applied according to the rules defined by the AWS API:
+    /// https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Filtering.html
+    // +optional
+    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    pub filters: Vec<Filter>, // `json:"filters,omitempty"`
+}
+
+/// Filter is a filter used to identify an AWS resource.
+#[derive(Clone, Debug, Default, Serialize, Deserialize)]
+#[serde(rename_all = "camelCase")]
+#[skip_serializing_none]
+pub struct Filter {
+    /// Name of the filter. Filter names are case-sensitive.
+    pub name: String, // `json:"name"`
+
+    /// Values includes one or more filter values. Filter values are case-sensitive.
+    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    pub values: Vec<String>, // `json:"values"`
+}
+
 /*  ============================================================================
 
 
